diff --git a/contrib/bloom/bloom.h b/contrib/bloom/bloom.h
index d5284f3..381d723 100644
--- a/contrib/bloom/bloom.h
+++ b/contrib/bloom/bloom.h
@@ -85,29 +85,29 @@ typedef struct BloomOptions
 typedef BlockNumber FreeBlockNumberArray[
 										 MAXALIGN_DOWN(
 		BLCKSZ - SizeOfPageHeaderData - MAXALIGN(sizeof(BloomPageOpaqueData))
 	   - MAXALIGN(sizeof(uint16) * 2 + sizeof(uint32) + sizeof(BloomOptions))
 													   ) / sizeof(BlockNumber)
 ];
 
 /* Metadata of bloom index */
 typedef struct BloomMetaPageData
 {
-	uint32		magickNumber;
+	uint32		magicNumber;
 	uint16		nStart;
 	uint16		nEnd;
 	BloomOptions opts;
 	FreeBlockNumberArray notFullPage;
 }	BloomMetaPageData;
 
-/* Magic number to distinguish bloom pages among anothers */
-#define BLOOM_MAGICK_NUMBER (0xDBAC0DED)
+/* Magic number to distinguish bloom pages among others */
+#define BLOOM_MAGIC_NUMBER (0xDBAC0DED)
 
 /* Number of blocks numbers fit in BloomMetaPageData */
 #define BloomMetaBlockN		(sizeof(FreeBlockNumberArray) / sizeof(BlockNumber))
 
 #define BloomPageGetMeta(page)	((BloomMetaPageData *) PageGetContents(page))
 
 typedef struct BloomState
 {
 	FmgrInfo	hashFn[INDEX_MAX_KEYS];
 	BloomOptions opts;			/* copy of options on index's metapage */
diff --git a/contrib/bloom/blutils.c b/contrib/bloom/blutils.c
index be056c3..a09744d 100644
--- a/contrib/bloom/blutils.c
+++ b/contrib/bloom/blutils.c
@@ -138,21 +138,21 @@ initBloomState(BloomState *state, Relation index)
 
 		buffer = ReadBuffer(index, BLOOM_METAPAGE_BLKNO);
 		LockBuffer(buffer, BUFFER_LOCK_SHARE);
 
 		page = BufferGetPage(buffer);
 
 		if (!BloomPageIsMeta(page))
 			elog(ERROR, "Relation is not a bloom index");
 		meta = BloomPageGetMeta(BufferGetPage(buffer));
 
-		if (meta->magickNumber != BLOOM_MAGICK_NUMBER)
+		if (meta->magicNumber != BLOOM_MAGIC_NUMBER)
 			elog(ERROR, "Relation is not a bloom index");
 
 		*opts = meta->opts;
 
 		UnlockReleaseBuffer(buffer);
 
 		index->rd_amcache = (void *) opts;
 	}
 
 	memcpy(&state->opts, index->rd_amcache, sizeof(state->opts));
@@ -413,21 +413,21 @@ BloomInitMetapage(Relation index)
 		index->rd_options = palloc0(sizeof(BloomOptions));
 	adjustBloomOptions((BloomOptions *) index->rd_options);
 
 	/* Initialize contents of meta page */
 	state = GenericXLogStart(index);
 	metaPage = GenericXLogRegister(state, metaBuffer, true);
 
 	BloomInitPage(metaPage, BLOOM_META);
 	metadata = BloomPageGetMeta(metaPage);
 	memset(metadata, 0, sizeof(BloomMetaPageData));
-	metadata->magickNumber = BLOOM_MAGICK_NUMBER;
+	metadata->magicNumber = BLOOM_MAGIC_NUMBER;
 	metadata->opts = *((BloomOptions *) index->rd_options);
 	((PageHeader) metaPage)->pd_lower += sizeof(BloomMetaPageData);
 
 	GenericXLogFinish(state);
 	UnlockReleaseBuffer(metaBuffer);
 }
 
 /*
  * Initialize options for bloom index.
  */
